@@ -14,7 +14,13 @@ import yarl
 from aiohttp import web
 
 
-__version__ = "0.19.1"
+<<<<<<< HEAD
+__version__ = "0.20.1"
+||||||| 24ef6b7
+__version__ = "0.19.0"
+=======
+__version__ = "0.19.2"
+>>>>>>> origin/develop
 __project__ = "aioauth-client"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "MIT"
@@ -217,6 +223,7 @@ class OAuth1Client(Client):
     def get_authorize_url(self, request_token=None, **params):
         """Return formatted authorization URL."""
         params.update({'oauth_token': request_token or self.oauth_token})
+        params.update(self.params)
         return self.authorize_url + '?' + urlencode(params)
 
     def request(self, method, url, params=None, **aio_kwargs):
@@ -1018,6 +1025,19 @@ class SlackClient(OAuth2Client):
         yield 'email', user.get('email')
 
 
+class TodoistClient(OAuth2Client):
+    """Support Todoist
+
+        * Dashboard: https://developer.todoist.com/appconsole.html
+        * Docs: https://developer.todoist.com/sync/v8/
+
+    """
+    authorize_url = 'https://todoist.com/oauth/authorize'
+    access_token_url = 'https://todoist.com/oauth/access_token'
+    base_url = 'https://todoist.com/rest/v1'
+    name = 'todoist'
+
+
 class TrelloClient(OAuth1Client):
     """Support Twitter.
 
